package
module
Version:
v0.0.0-...-88fa533
Opens a new window with list of versions in this module.
Published: Sep 3, 2022
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
func Divide(num1, num2 int) int
Divide retorna la división de dos números enteros
func Multiplica(num1, num2 int) int
Multiplica retorna la multiplicacion de dos números enteros
func Resta(num1, num2 int) int
Resta retorna la Resta de dos números enteros
Suma retorna la suma de dos números enteros
Source Files
¶
Click to show internal directories.
Click to hide internal directories.